@@ -4,7 +4,7 @@
  * The actual fread() function as a non-inline
  */
 
-#define __NO_FREAD_FWRITE_INLINES
+#define __NO_STDIO_INLINES
 #include <stdio.h>
 
 size_t fread(void *ptr, size_t size, size_t nmemb, FILE * f)
