@@ -12,9 +12,8 @@ int main(int argc, char *argv[], char *envp[])
 
 	/* Test argc/argv */
 	printf("argc = %d, argv = %p\n", argc, argv);
-	for (i = 0; i < argc; i++) {
+	for (i = 0; i < argc; i++)
 		printf("argv[%2d] = %s\n", i, argv[i]);
-	}
 
 	/* Test environ */
 	for (i = 0; envp[i]; i++)
